==> Services_Hatena-0.0.5.tgz: Services_Hatena-0.0.5/Hatena/asin.php <==
<?php
/* vim: set expandtab tabstop=4 shiftwidth=4 softtabstop=4: */

/**
 * asin class
 *
 * PHP version 5
 *
 * LICENSE: This source file is subject to version 3.0 of the PHP license
 * that is available through the world-wide-web at the following URI:
 * http://www.php.net/license/3_0.txt.  If you did not receive a copy of
 * the PHP License and are unable to obtain it through the web, please
 * send a note to license@php.net so we can mail you a copy immediately.
 *
 * @category   Services
 * @package    Services_Hatena
 * @author     gooooooogle
 * @copyright  2006 gooooooogle
 * @license    http://www.php.net/license/3_0.txt  PHP License 3.0
 * @version    CVS: $Id$
 */

/**
 * @class Services_Hatena_asin
 *
 * This is asin class.
 * for the Hatena API.
 *
 * @category   Services
 * @package    Services_Hatena
 * @author     gooooooogle
 * @copyright  2006 gooooooogle
 * @license    http://www.php.net/license/3_0.txt  PHP License 3.0
 * @version    CVS: $Id$
 */
class Services_Hatena_asin extends Services_Hatena_base {
    protected $params;

    /**
     * @fn Services_Hatena_asin
     * @brief constructer for Services_Hatena_asin class
     *
     * @access  public
     */
    public function Services_Hatena_asin() {}

    /**
     * @fn execute
     * @brief you will be able to know number of an arbitrary used ASIN code
     *
     * @access  public
     * @param   string ASIN code
     * @return  string number of an arbitrary used ASIN code
     */
    public function execute($asin) {
        mb_internal_encoding('euc');
        require_once "XML/RPC.php";

        $this->params = new XML_RPC_Value($asin,"string");

        $msg      = new XML_RPC_Message("bookmark.getAsinCount", array($this->params));
        $client   = new XML_RPC_Client("/xmlrpc", "b.hatena.ne.jp", 80);
        $response = $client->send($msg);

        if (!$response->faultCode()) {
          $r = $response->value()->scalarval();
          $this->result = $r[$asin]->me["int"];
          return $this->getResult();
        }
        else {
          /** i do nothing */
        }
    }
}

==> Services_Hatena-0.0.7.tgz: Services_Hatena-0.0.7/Hatena/asin.php <==
<?php
/* vim: set expandtab tabstop=4 shiftwidth=4 softtabstop=4: */

/**
 * asin class
 *
 * PHP version 5
 *
 * LICENSE: This source file is subject to version 3.0 of the PHP license
 * that is available through the world-wide-web at the following URI:
 * http://www.php.net/license/3_0.txt.  If you did not receive a copy of
 * the PHP License and are unable to obtain it through the web, please
 * send a note to license@php.net so we can mail you a copy immediately.
 *
 * @category   Services
 * @package    Services_Hatena
 * @author     gooooooogle
 * @copyright  2006 gooooooogle
 * @license    http://www.php.net/license/3_0.txt  PHP License 3.0
 * @version    CVS: $Id$
 */

/**
 * 拾쥯饹
 *
 * Υ饹ϤϤƤʤ拾쥯APIѤ뤿Υ饹Ǥ
 *
 * @category   Services
 * @package    Services_Hatena
 * @author     gooooooogle
 * @copyright  2006 gooooooogle
 * @license    http://www.php.net/license/3_0.txt  PHP License 3.0
 * @version    CVS: $Id$
 */
class Services_Hatena_asin extends Services_Hatena_base {
    /**
     * 󥹥ȥ饯
     *
     * @access  public
     */
    public function Services_Hatena_asin() {}

    /**
     * ¹Դؿ
     *
     * ǤդASIN ɤˤĤ拾쥯֤ޤ
     *
     * @access  public
     * @param   string $asin ASIN 
     * @return  string 拾쥯
     */
    public function execute($asin) {
        mb_internal_encoding('euc');
        require_once "XML/RPC.php";

        $params = new XML_RPC_Value($asin,"string");

        $msg      = new XML_RPC_Message("bookmark.getAsinCount", array($params));
        $client   = new XML_RPC_Client("/xmlrpc", "b.hatena.ne.jp", 80);
        $response = $client->send($msg);

        if (!$response->faultCode()) {
          $r = $response->value()->scalarval();
          $this->result = $r[$asin]->me["int"];
          return $this->getResult();
        }
        else {
          // ⤷ޤ
        }
    }
}
